<?php
// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	die;
}

if ( ! class_exists( 'BestBugFBOptions' ) ) {
	/**
	 * VC BestBugFBOptions Class
	 *
	 * @since    1.0
	 */
	class BestBugFBOptions {

		public $defaultFooter;
		public $post_types;
		public $maxWidth;

		public $all_posttypes;

		public $allFooters = array(
			'' => 'Choose a Footer',
		);

		function __construct() {
			add_action( 'init', array( &$this, 'init' ) );
		}

		public function init() {

			$this->all_posttypes = get_post_types( array( 'public' => true ) );
			unset( $this->all_posttypes['attachment'] );

			$args  = array(
				'posts_per_page' => - 1,
				'post_type'      => 'bbfb_content',
				'orderby'        => 'title',
				'order'          => 'ASC',
			);
			$query = new WP_Query( $args );

			if ( $query->post_count > 0 ) {
				foreach ( $query->posts as $key => $post ) {
					$this->allFooters[ $post->post_name ] = $post->post_title;
				}
			}

			$this->defaultFooter = BBFBHelper::$defaultFooter;
			$this->post_types    = BBFBHelper::$post_types;
			$this->maxWidth      = BBFBHelper::$max_width;

			add_action( 'admin_menu', array( &$this, 'admin_menu' ) );
		}

		public function admin_menu() {
			add_submenu_page(
				'edit.php?post_type=bbfb_content',
				esc_html( 'Settings', 'bestbug' ),
				esc_html( 'Settings', 'bestbug' ),
				'manage_options',
				'bb_footer_builder',
				array( &$this, 'generalSettings' )
			);

			if ( isset( $_POST['bbfb_update_general'] ) && ( '1' === $_POST['bbfb_update_general'] || 'true' === $_POST['bbfb_update_general'] ) ) {
				$this->update_general();
			}

		}

		public function generalSettings() {
			include_once( 'templates/bbfb_general.tpl.php' );
		}

		public function update_general() {

			foreach ( $_POST as $key => $value ) {
				$this->$key = $value;
			}

			if ( self::update_option( BESTBUG_FB_DEFAULT_FOOTER, $this->defaultFooter ) || self::update_option( BESTBUG_FB_POST_TYPES, $this->post_types ) ) {
				$this->notice = esc_html__( 'Updated', 'bestbug' );
				add_action( 'admin_notices', array( $this, 'update_notice' ) );
			} else {
				$this->notice = esc_html__( 'Irks! An error has occurred.', 'bestbug' );
				add_action( 'admin_notices', array( $this, 'error_notice' ) );
			}
		}

		public function update_option( $option_name, $option_value ) {
			$option_exists = ( get_option( $option_name, null ) !== null );
			if ( $option_exists != null ) {
				return update_option( $option_name, $option_value );
			} else {
				return add_option( $option_name, $option_value );
			}
		}

		public function error_notice() {
			$class = 'notice notice-error';
			printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $this->notice );
		}

		public function update_notice() {
			$class = 'notice notice-updated updated';
			printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $this->notice );
		}

	}

	new BestBugFBOptions();
}
