<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Register Posttypes Class
 *
 * @package Core
 */
class BBFB_Register_Posttypes {

	public $posttypes;

	/**
	 * The constructor.
	 */
	public function __construct() {
		// Do register
		add_action( 'init', array( $this, 'register_posttypes' ) );
	}

	/**
	 * The Register posttypes.
	 */
	public function register_posttypes() {

		$this->posttypes = apply_filters( 'bbfb_posttypes', array() );
		if ( empty( $this->posttypes ) ) {
			return;
		}

		foreach ( $this->posttypes as $slug => $posttype ) {
			if ( ! empty( $slug ) ) {
				register_post_type( $slug, $posttype );
			}
		}

	}

}

new BBFB_Register_Posttypes();


class BBFB_FooterContent {

	/**
	 * The constructor.
	 */
	public function __construct() {
		// Add filter
		add_filter( 'bbfb_posttypes', array( $this, 'register_posttypes' ) );
		add_action( 'activate_bb_footer_builder', array( $this, 'init' ) );
	}

	/**
	 * The Register posttypes.
	 */
	public function register_posttypes() {

		if ( empty( $posttypes ) ) {
			$posttypes = array();
		}

		$labels                    = array(
			'name'               => _x( 'Footers', 'Post Type General Name', 'lamblue' ),
			'singular_name'      => _x( 'Footer', 'Post Type Singular Name', 'lamblue' ),
			'menu_name'          => __( 'Footers', 'lamblue' ),
			'name_admin_bar'     => __( 'Footers', 'lamblue' ),
			'parent_item_colon'  => __( 'Parent Menu:', 'lamblue' ),
			'all_items'          => __( 'All Footers', 'lamblue' ),
			'add_new_item'       => __( 'Add New Footer', 'lamblue' ),
			'add_new'            => __( 'Add New', 'lamblue' ),
			'new_item'           => __( 'New Footer', 'lamblue' ),
			'edit_item'          => __( 'Edit Footer', 'lamblue' ),
			'update_item'        => __( 'Update Footer', 'lamblue' ),
			'view_item'          => __( 'View Footer', 'lamblue' ),
			'search_items'       => __( 'Search Footer', 'lamblue' ),
			'not_found'          => __( 'Not found', 'lamblue' ),
			'not_found_in_trash' => __( 'Not found in Trash', 'lamblue' ),
		);
		$args                      = array(
			'label'               => __( 'Footer', 'lamblue' ),
			'description'         => __( 'Footer', 'lamblue' ),
			'labels'              => $labels,
			'supports'            => array( 'title', 'editor', ),
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => true,
			'menu_position'       => 13,
			'menu_icon'           => 'dashicons-schedule',
			'show_in_admin_bar'   => true,
			'show_in_nav_menus'   => true,
			'can_export'          => true,
			'has_archive'         => false,
			'exclude_from_search' => true,
			'publicly_queryable'  => false,
			'rewrite'             => false,
			'capability_type'     => 'page',
		);
		$posttypes['bbfb_content'] = $args;

		return $posttypes;
	}

}

new BBFB_FooterContent;
