<?php
add_shortcode( 'bbfb_social', 'bbfb_social' );

function bbfb_social( $atts ) {

	$atts = shortcode_atts( array(
		'socials'    => '',
		'style'      => '',
		'color'      => '',
		'text_align' => '',
		'el_class'   => '',
	), $atts );

	extract( $atts );

	$socials = (array) vc_param_group_parse_atts( $socials );

	if ( count( $socials ) <= 0 ) {
		return;
	}

	$html = '<ul class="bbfb-social bbfb-social-' . esc_attr( $style ) . ' bbfb-social-' . esc_attr( $color ) . ' ' . esc_attr( $el_class ) . ' ' . esc_attr( $text_align ) . '">';

	foreach ( $socials as $social ) {
		// Get icon
		$icon_class = isset( $social[ 'icon_' . $social['icon_lib'] ] ) ? esc_attr( $social[ 'icon_' . $social['icon_lib'] ] ) : 'icon-default';
		vc_icon_element_fonts_enqueue( $social['icon_lib'] );
		// Get link
		$link_html   = '';
		$link        = vc_build_link( $social['link'] );
		$link_url    = ( isset( $link['url'] ) && ( $link['url'] != '' ) ) ? $link['url'] : '#';
		$link_text   = ( isset( $link['title'] ) && ( $link['title'] != '' ) ) ? $link['title'] : esc_html__( 'Click Me', 'tm-trio' );
		$link_target = ( isset( $link['target'] ) && ( $link['target'] != '' ) ) ? $link['target'] : '_self';
		$link_rel    = ( isset( $link['rel'] ) && ( $link['rel'] != '' ) ) ? $link['rel'] : 'nofollow';

		$html .= '<li class="bbfb-social-item"><a href="' . esc_url( $link_url ) . '" title="' . esc_attr( $link_text ) . '" target="' . esc_attr( $link_target ) . '" rel="' . esc_attr( $link_rel ) . '"><i class="' . esc_attr( $icon_class ) . '"></i></a></li>';
	}

	$html .= '</ul>';

	return $html;
}

if ( defined( 'WPB_VC_VERSION' ) && function_exists( 'vc_add_param' ) ) {
	vc_map( array(
		'name'                      => esc_html__( 'Social', 'bestbug' ),
		'base'                      => 'bbfb_social',
		'category'                  => esc_html( sprintf( esc_html__( 'by %s', 'bestbug' ), BBFOOTER_DESIGNER_CATEGORY ) ),
		'icon'                      => '',
		'allowed_container_element' => 'vc_row',
		'params'                    => array(
			array(
				'type'       => 'param_group',
				'heading'    => esc_html__( 'Socials', 'tm-trio' ),
				'param_name' => 'socials',
				'params'     => array(
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Icon library', 'bestbug' ),
						'value'       => array(
							esc_html__( 'Font Awesome', 'bestbug' ) => 'fontawesome',
						),
						'param_name'  => 'icon_lib',
						'description' => esc_html__( 'Select icon library.', 'bestbug' ),
						'dependency'  => array( 'element' => 'icon_type', 'value' => array( 'custom' ) ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'bestbug' ),
						'param_name'  => 'icon_fontawesome',
						'value'       => 'fa fa-adjust',
						'settings'    => array(
							'emptyIcon'    => false,
							'iconsPerPage' => 4000,
						),
						'dependency'  => array(
							'element' => 'icon_lib',
							'value'   => 'fontawesome',
						),
						'description' => esc_html__( 'Select icon from library.', 'bestbug' ),
					),
					array(
						'type'        => 'vc_link',
						'heading'     => esc_html__( 'Link', 'bestbug' ),
						'param_name'  => 'link',
						'admin_label' => true,
					),
				)
			),

			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Style', 'bestbug' ),
				'value'       => array(
					'Default'                                => '',
					esc_html__( 'Inline Normal', 'bestbug' ) => 'inline-normal',
				),
				'param_name'  => 'style',
				'admin_label' => true,
				'save_always' => true,
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Color', 'bestbug' ),
				'value'       => array(
					esc_html__( 'Dark', 'bestbug' )  => 'dark',
					esc_html__( 'Light', 'bestbug' ) => 'light',
				),
				'param_name'  => 'color',
				'admin_label' => true,
				'save_always' => true,
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text align', 'bestbug' ),
				'value'       => array(
					'Default'                         => '',
					esc_html__( 'Left', 'bestbug' )   => 'text-left',
					esc_html__( 'Center', 'bestbug' ) => 'text-center',
					esc_html__( 'Right', 'bestbug' )  => 'text-right',
				),
				'param_name'  => 'text_align',
				'admin_label' => true,
				'save_always' => true,
			),
			array(
				"type"       => "textfield",
				"class"      => "",
				"heading"    => esc_html__( 'Custom Class CSS', 'bestbug' ),
				"param_name" => "el_class",
			),
		),
	) );

}
