<?php
/*
Plugin Name: Footer Designer
Description: Easy way to create any footers you can imagine.
Author: BestBug
Version: 1.3
Author URI: http://footer-designer.lamblue.com/
Text Domain: bestbug
Domain Path: /languages
*/

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}


defined( 'BBFOOTER_DESIGNER_VERSION' ) or define( 'BBFOOTER_DESIGNER_VERSION', '1.0' );
defined( 'BBFOOTER_DESIGNER_CATEGORY' ) or define( 'BBFOOTER_DESIGNER_CATEGORY', 'Footer Designer' );

defined( 'BESTBUG_FB_URL' ) or define( 'BESTBUG_FB_URL', plugins_url( '/', __FILE__ ) );

defined( 'BESTBUG_FB_PATH' ) or define( 'BESTBUG_FB_PATH', basename( dirname( __FILE__ ) ) );
defined( 'BESTBUG_FB_TEXTDOMAIN' ) or define( 'BESTBUG_FB_TEXTDOMAIN', plugins_url( '/', __FILE__ ) );
defined( 'BESTBUG_FB_SHORTCODE' ) or define( 'BESTBUG_FB_SHORTCODE', 'bb_fb' );

defined( 'BESTBUG_FB_DEFAULT_FOOTER' ) or define( 'BESTBUG_FB_DEFAULT_FOOTER', 'bbfb_default_footer' );
defined( 'BESTBUG_FB_POST_TYPES' ) or define( 'BESTBUG_FB_POST_TYPES', 'bbfb_post_types' );

defined( 'BESTBUG_FB_FOOTER_POSTTYPE' ) or define( 'BESTBUG_FB_FOOTER_POSTTYPE', 'bbfb_content' );

defined( 'BESTBUG_FB_METABOX_FOOTER' ) or define( 'BESTBUG_FB_METABOX_FOOTER', '_bb_footer' );
defined( 'BESTBUG_FB_METABOX_MAX_WIDTH' ) or define( 'BESTBUG_FB_METABOX_MAX_WIDTH', '_bb_footer_max_width' );


if ( ! function_exists( 'bb_footer_builder_activate' ) ) {

	function bb_footer_builder_activate() {
		$pt_array = ( $pt_array = get_option( 'wpb_js_content_types' ) ) ? ( $pt_array ) : array( 'page' );
		if ( ! in_array( BESTBUG_FB_FOOTER_POSTTYPE, $pt_array ) ) {
			$pt_array[] = BESTBUG_FB_FOOTER_POSTTYPE;
		}
		update_option( 'wpb_js_content_types', $pt_array );
	}

	register_activation_hook( __FILE__, 'bb_footer_builder_activate' );

}

if ( ! class_exists( 'BestBugFooterBuilder' ) ) {
	/**
	 * BestBugFooterBuilder Class
	 *
	 * @since    1.0
	 */
	class BestBugFooterBuilder {


		/**
		 * Constructor, checks for Visual Composer and defines hooks
		 *
		 * @return    void
		 * @since    1.0
		 */
		function __construct() {

			include "includes/helper.php";

			include "includes/admin/admin.php";

			include "includes/posttype.php";

			add_action( 'init', array( $this, 'load_after_init' ) );

			add_action( 'init', array( $this, 'init' ) );
			add_action( 'init', array( $this, 'add_new_vccustom' ) );

			//Ultimate addon
			add_action( 'wp_enqueue_scripts', array( $this, 'aio_front_scripts' ), 100 );

			include "includes/filter.php";

			add_action( 'plugins_loaded', array( $this, 'loadTextDomain' ) );

			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'add_action_links' ) );

			// add_filter( 'body_class', array( $this, 'add_body_class' ) );
		}

		function load_after_init() {
			include "includes/shortcodes/index.php";
		}

		function add_new_vccustom() {
			global $vc_row_layouts;
			$vc_row_layouts[] = array( 'cells'      => '15_15_15_15_15',
			                           'mask'       => '530',
			                           'title'      => '1/5 + 1/5 + 1/5 + 1/5 + 1/5',
			                           'icon_class' => 'l_15_15_15_15_15'
			);

			return $vc_row_layouts;
		}

		public function add_action_links( $links ) {
			$mylinks = array(
				'<a href="' . admin_url( 'admin.php?page=bb_footer_builder' ) . '">Settings</a>',
			);

			return array_merge( $mylinks, $links );
		}

		public function init() {
			if ( is_admin() ) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );
		}

		public function adminEnqueueScripts() {
			wp_enqueue_style( 'bbfb-admin', BESTBUG_FB_URL . '/assets/admin/css/admin.css' );
		}

		public function aio_front_scripts() {
			if ( defined( 'ULTIMATE_VERSION' ) ) {
				wp_enqueue_style( 'ultimate-style-min' );
			}
		}

		public function enqueueScripts() {
			wp_enqueue_style( 'bbfb', BESTBUG_FB_URL . '/assets/css/bbfb.css' );

			$footer_name = BBFBHelper::$defaultFooter;

			if ( is_singular() && array_key_exists( get_post_type(), BBFBHelper::$post_types ) ) {
				$metadata = apply_filters( 'bbfb_get_footer_metadata', get_post_meta( get_the_ID(), BESTBUG_FB_METABOX_FOOTER, true ) );
				if ( $metadata ) {
					$footer_name = $metadata;
				}
			}

			if ( isset( $_REQUEST['bbfb_content'] ) && ! empty( $_REQUEST['bbfb_content'] ) ) {
				$footer_name = esc_attr( $_REQUEST['bbfb_content'] );
			}

			$footer_name = apply_filters( 'bbfb_get_footer_metadata_all', $footer_name );

			if ( ! $footer_name ) {
				return;
			}

			$footer = get_page_by_path( $footer_name, OBJECT, BESTBUG_FB_FOOTER_POSTTYPE );

			if ( ! $footer ) {
				return;
			}

			$custom_css = get_post_meta( $footer->ID, '_wpb_shortcodes_custom_css', true );

			$selector = '#bb-footer-inside-' . $footer_name;
			$maxWidth = get_post_meta( $footer->ID, BESTBUG_FB_METABOX_MAX_WIDTH, true );

			if ( ! $maxWidth ) {
				$selector = '.bb-footer-inside';
				$maxWidth = BBFBHelper::$max_width;
			}
			if ( $maxWidth ) {
				if ( is_numeric( $maxWidth ) ) {
					if ( $maxWidth <= 100 ) {
						$maxWidth .= '%';
					} else {
						$maxWidth .= 'px';
					}
					$custom_css .= '@media (min-width: 1025px) {' . $selector . ' { max-width: ' . $maxWidth . '; } }';

				} else {
					$custom_css .= $selector . ' { max-width: ' . $maxWidth . '; }';
				}
			}

			wp_add_inline_style( 'bbfb', $custom_css );
		}

		public function loadTextDomain() {
			load_plugin_textdomain( BESTBUG_FB_TEXTDOMAIN, false, BESTBUG_FB_PATH . '/languages/' );
		}
	}

	new BestBugFooterBuilder();
}
